@@ -1,7 +1,7 @@
 import unittest
 from .context import jacobsjsondoc
 from jacobsjsondoc.reference import JsonPointer
-from jacobsjsondoc.document import create_document, DocReference, DocObject, Document
+from jacobsjsondoc.document import create_document, DocReference, DocObject, Document, UnableToLoadDocument, PathReferenceResolutionError
 from jacobsjsondoc.loader import PrepopulatedLoader
 from jacobsjsondoc.options import ParseOptions, RefResolutionMode
 import json
@@ -110,9 +110,6 @@ class TestIdTagging(unittest.TestCase):
     def test_fooproperty_has_correct_id(self):
         self.assertEqual(self.doc['objects']['fooProperty'].base_uri, "http://example.com/schema.json#fooprop")
 
-    def test_dictionary_contents(self):
-        self.assertEqual(len(self.doc._pointers.controller._document_cache), 3)
-
     def test_dictionary_has_barprop(self):
         barprop = self.doc._pointers.controller._document_cache["http://example.com/schema.json#barprop"]
         self.assertEqual(barprop['$id'], "#barprop")
@@ -294,6 +291,7 @@ class TestBaseUriChange(unittest.TestCase):
 
     def test_types(self):
         self.assertIsInstance(self.doc["type"], str)
+        self.assertIsInstance(self.doc["properties"], DocObject)
         self.assertIsInstance(self.doc["properties"]["list"], DocReference)
         self.assertIsInstance(self.doc["definitions"]["baz"]["definitions"]["bar"]["items"], DocReference)
 
@@ -318,14 +316,14 @@ class TestBaseUriChange(unittest.TestCase):
         self.assertIsInstance(dereffed, DocObject)
 
     def test_items_reference_resolution(self):
-        with self.assertRaises(KeyError) as context:
+        with self.assertRaises(UnableToLoadDocument) as context:
             # We don't really want to have to load the remote reference, so we'll just check that the
             # exception shows the correct URI to the remote.
             dereffed = self.doc["definitions"]["baz"]["definitions"]["bar"]["items"].resolve()
             self.assertIn("http://localhost:1234/baseUriChangeFolderInSubschema/folderInteger.json", str(context.exception))
 
     def test_doc2_items_resolution(self):
-        with self.assertRaises(KeyError) as context:
+        with self.assertRaises(UnableToLoadDocument) as context:
             # We don't really want to have to load the remote reference, so we'll just check that the
             # exception shows the correct URI to the remote.
             dereffed = self.doc2["items"]["items"].resolve()
@@ -333,4 +331,22 @@ class TestBaseUriChange(unittest.TestCase):
 
     def test_doc3_resolution(self):
         self.assertIsInstance(self.doc3["properties"]["foo"]["allOf"][0], DocReference)
-        self.assertIsInstance(self.doc3["allOf"][0], DocReference)
\ No newline at end of file
+        self.assertIsInstance(self.doc3["allOf"][0], DocReference)
+
+class TestInvalid(unittest.TestCase):
+
+    def setUp(self):
+        self.data = """
+        foo:
+            $ref: "#/doesnt/exist"
+        bar:
+            value: 1
+        """
+        ppl = PrepopulatedLoader()
+        ppl.prepopulate("1", self.data)
+        self.doc = create_document(uri="1", loader=ppl)
+    
+    def test_local_ref_goes_nowhere(self):
+        self.assertIsInstance(self.doc['foo'], DocReference)
+        with self.assertRaises(PathReferenceResolutionError) as context:
+            self.doc['foo'].resolve()
\ No newline at end of file
